==> haskell-tamarin-prover-theory-1.2.3-11-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tamarin-prover-theory.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tamarin-prover-theory
version: 1.2.3
id: tamarin-prover-theory-1.2.3-4lTKqBHFvRAJTqSe2QfWYu
key: tamarin-prover-theory-1.2.3-4lTKqBHFvRAJTqSe2QfWYu
license: GPL
copyright: Benedikt Schmidt, Simon Meier, ETH Zurich, 2010-2012
maintainer: Benedikt Schmidt <benedikt.schmidt@inf.ethz.ch>
homepage: http://www.infsec.ethz.ch/research/software/tamarin
synopsis: Security protocol types and constraint solver library for the tamarin prover.
description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).
    .
    This library provides the types to represent security
    protocol, and it implements the constraint solver.
category: Theorem Provers
author: Benedikt Schmidt <benedikt.schmidt@inf.ethz.ch>,
        Simon Meier <simon.meier@inf.ethz.ch>
exposed: True
indefinite: False
exposed-modules:
    Theory Theory.Constraint.Solver
    Theory.Constraint.Solver.Contradictions
    Theory.Constraint.Solver.Goals Theory.Constraint.Solver.ProofMethod
    Theory.Constraint.Solver.Reduction
    Theory.Constraint.Solver.Simplify Theory.Constraint.Solver.Sources
    Theory.Constraint.Solver.Types Theory.Constraint.System
    Theory.Constraint.System.Constraints Theory.Constraint.System.Dot
    Theory.Constraint.System.Guarded Theory.Constraint.System.JSON
    Theory.Model Theory.Model.Atom Theory.Model.Fact
    Theory.Model.Formula Theory.Model.Rule Theory.Model.Signature
    Theory.Proof Theory.Text.Parser Theory.Text.Parser.Token
    Theory.Text.Pretty Theory.Tools.AbstractInterpretation
    Theory.Tools.EquationStore Theory.Tools.InjectiveFactInstances
    Theory.Tools.IntruderRules Theory.Tools.LoopBreakers
    Theory.Tools.RuleVariants Theory.Tools.Wellformedness
abi: 93d4979f6974db57ea9c812790f07712
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/tamarin-prover-theory-1.2.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/tamarin-prover-theory-1.2.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/tamarin-prover-theory-1.2.3
hs-libraries: HStamarin-prover-theory-1.2.3-4lTKqBHFvRAJTqSe2QfWYu
depends:
    aeson-1.2.4.0-IxpmF2XxtfM2bzjPAR2gMF
    aeson-pretty-0.8.7-2n9vyxhNKA4Dfn1oVLbYjX base-4.10.1.0
    binary-0.8.5.1 bytestring-0.10.8.2 containers-0.5.10.2
    deepseq-1.4.3.0 dlist-0.8.0.4-8Td44GecKNEJmy7QK3HIQc
    fclabels-2.0.3.3-4WNPtbHFlNRFH87gHrbcA6
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    parallel-3.2.1.1-6PIhrl6oqe7Af1Z2sa6T1
    parsec-3.1.13.0-F9Bf3y6KXh0ILPjymhJoOp process-1.6.1.0
    safe-0.3.15-EroU33EYnr02fGSZYGiX97
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz transformers-0.5.2.0
    uniplate-1.6.12-By8lBp5iSPwHN1UdSjtyhe
    tamarin-prover-utils-1.2.3-LRaNfc8SJzb44WC7Bg29VZ
    tamarin-prover-term-1.2.3-AiYSm76tR4MKVx26fIlMp4
abi-depends: aeson-1.2.4.0-IxpmF2XxtfM2bzjPAR2gMF=117e2ccb320a02562b7dab8dac8cab03
             aeson-pretty-0.8.7-2n9vyxhNKA4Dfn1oVLbYjX=ce99f4ed93ff2ced722cba3594297e8e
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             binary-0.8.5.1=33c677d3ced9a5afbc7b354509494653
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             dlist-0.8.0.4-8Td44GecKNEJmy7QK3HIQc=891025a77d043cfd28f763ce7f5a4b16
             fclabels-2.0.3.3-4WNPtbHFlNRFH87gHrbcA6=77fb45eb89f425325c76d910956f050c
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             parallel-3.2.1.1-6PIhrl6oqe7Af1Z2sa6T1=f329a0732f0d1ccfb717a7145bfd3a72
             parsec-3.1.13.0-F9Bf3y6KXh0ILPjymhJoOp=b942a04aec0a266706b2e8e67bd137e3
             process-1.6.1.0=e78440f24fd9cc3300a1da2a92a47757
             safe-0.3.15-EroU33EYnr02fGSZYGiX97=604c7b7c109a34b58d71795df287548a
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             uniplate-1.6.12-By8lBp5iSPwHN1UdSjtyhe=243b511ea6e7b49156b7e9f3cef198b3
             tamarin-prover-utils-1.2.3-LRaNfc8SJzb44WC7Bg29VZ=3906488fabaf470f4f56104ad1534323
             tamarin-prover-term-1.2.3-AiYSm76tR4MKVx26fIlMp4=b02cc50fd02c88b0c174c5aeaf088111
haddock-interfaces: /usr/share/doc/haskell-tamarin-prover-theory/html/tamarin-prover-theory.haddock
haddock-html: /usr/share/doc/haskell-tamarin-prover-theory/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tamarin-prover-theory-1.4.0-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tamarin-prover-theory.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tamarin-prover-theory
version: 1.4.0
id: tamarin-prover-theory-1.4.0-28cQSTmG0ctGC71K3SGtX5
key: tamarin-prover-theory-1.4.0-28cQSTmG0ctGC71K3SGtX5
license: GPL
copyright: Benedikt Schmidt, Simon Meier, Jannik Dreier, Ralf Sasse, ETH Zurich, 2010-2018
maintainer: Simon Meier <simon.meier@inf.ethz.ch>,
            Jannik Dreier <research@jannikdreier.net>,
            Ralf Sasse <ralf.sasse@gmail.com>
homepage: https://tamarin-prover.github.io/
synopsis: Security protocol types and constraint solver library for the tamarin prover.
description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).
    .
    This library provides the types to represent security
    protocol, and it implements the constraint solver.
category: Theorem Provers
author: Benedikt Schmidt <benedikt.schmidt@inf.ethz.ch>,
        Simon Meier <simon.meier@inf.ethz.ch>,
        Jannik Dreier <research@jannikdreier.net>,
        Ralf Sasse <ralf.sasse@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Theory Theory.Constraint.Solver
    Theory.Constraint.Solver.Contradictions
    Theory.Constraint.Solver.Goals Theory.Constraint.Solver.ProofMethod
    Theory.Constraint.Solver.Reduction
    Theory.Constraint.Solver.Simplify Theory.Constraint.Solver.Sources
    Theory.Constraint.Solver.Types Theory.Constraint.System
    Theory.Constraint.System.Constraints Theory.Constraint.System.Dot
    Theory.Constraint.System.Guarded Theory.Constraint.System.JSON
    Theory.Model Theory.Model.Atom Theory.Model.Fact
    Theory.Model.Formula Theory.Model.Rule Theory.Model.Signature
    Theory.Proof Theory.Text.Parser Theory.Text.Parser.Token
    Theory.Text.Pretty Theory.Tools.AbstractInterpretation
    Theory.Tools.EquationStore Theory.Tools.InjectiveFactInstances
    Theory.Tools.IntruderRules Theory.Tools.LoopBreakers
    Theory.Tools.RuleVariants Theory.Tools.Wellformedness
abi: ef59aadc155b8a14447130ffb61be69d
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/tamarin-prover-theory-1.4.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/tamarin-prover-theory-1.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/tamarin-prover-theory-1.4.0
hs-libraries: HStamarin-prover-theory-1.4.0-28cQSTmG0ctGC71K3SGtX5
depends:
    aeson-1.2.4.0-Li9ssAeTb9P7oUJPRvxFf8
    aeson-pretty-0.8.7-6gPs1k9O6qLImLTHGKjLQ1 base-4.10.1.0
    binary-0.8.5.1 bytestring-0.10.8.2 containers-0.5.10.2
    deepseq-1.4.3.0 dlist-0.8.0.4-8Td44GecKNEJmy7QK3HIQc
    fclabels-2.0.3.3-4WNPtbHFlNRFH87gHrbcA6
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    parallel-3.2.1.1-6PIhrl6oqe7Af1Z2sa6T1
    parsec-3.1.13.0-F9Bf3y6KXh0ILPjymhJoOp process-1.6.1.0
    safe-0.3.15-EroU33EYnr02fGSZYGiX97
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz transformers-0.5.2.0
    uniplate-1.6.12-By8lBp5iSPwHN1UdSjtyhe
    tamarin-prover-utils-1.4.0-KAh5AYoM0Ce6frpfn5dHNP
    tamarin-prover-term-1.4.0-4wrIa0WSIrfBkhpdG5N9l8
abi-depends: aeson-1.2.4.0-Li9ssAeTb9P7oUJPRvxFf8=b6a260f9adf71cfb6ea790a11437cd4d
             aeson-pretty-0.8.7-6gPs1k9O6qLImLTHGKjLQ1=6f473dabe49a4ad5c0219b939b47860c
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             binary-0.8.5.1=33c677d3ced9a5afbc7b354509494653
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             dlist-0.8.0.4-8Td44GecKNEJmy7QK3HIQc=891025a77d043cfd28f763ce7f5a4b16
             fclabels-2.0.3.3-4WNPtbHFlNRFH87gHrbcA6=77fb45eb89f425325c76d910956f050c
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             parallel-3.2.1.1-6PIhrl6oqe7Af1Z2sa6T1=f329a0732f0d1ccfb717a7145bfd3a72
             parsec-3.1.13.0-F9Bf3y6KXh0ILPjymhJoOp=b942a04aec0a266706b2e8e67bd137e3
             process-1.6.1.0=e78440f24fd9cc3300a1da2a92a47757
             safe-0.3.15-EroU33EYnr02fGSZYGiX97=604c7b7c109a34b58d71795df287548a
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             uniplate-1.6.12-By8lBp5iSPwHN1UdSjtyhe=243b511ea6e7b49156b7e9f3cef198b3
             tamarin-prover-utils-1.4.0-KAh5AYoM0Ce6frpfn5dHNP=9e0e3109dd02bbfe33e7c96802f8f79e
             tamarin-prover-term-1.4.0-4wrIa0WSIrfBkhpdG5N9l8=7bfd01ffb5415af6960755db642ff777
haddock-interfaces: /usr/share/doc/haskell-tamarin-prover-theory/html/tamarin-prover-theory.haddock
haddock-html: /usr/share/doc/haskell-tamarin-prover-theory/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
